
'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = 0;
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(If left blank, owner will be admin)",
    "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)": "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)",
    "(at least {placeholder} characters)": "(at least {placeholder} characters)",
    "(current notification)": "(th\u00f4ng b\u00e1o hi\u1ec7n t\u1ea1i)",
    "(current version)": "(phi\u00ean b\u1ea3n hi\u1ec7n t\u1ea1i)",
    "1 cell copied": "1 cell copied",
    "1 filter": "L\u1ecdc 1",
    "1 hidden property": "1 hidden property",
    "1 month ago": "1 th\u00e1ng tr\u01b0\u1edbc",
    "1 preset hidden property": "1 preset hidden property",
    "1 record selected": "1 record selected",
    "1 row is copied.": "1 row is copied.",
    "1 sort": "S\u1eafp x\u1ebfp 1",
    "1 week ago": "1 tu\u1ea7n tr\u01b0\u1edbc",
    "3 days ago": "3 ng\u00e0y tr\u01b0\u1edbc",
    "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
    "A file with the same name already exists in this folder.": "M\u1ed9t file tr\u00f9ng t\u00ean \u0111\u00e3 t\u1ed3n t\u1ea1i trong th\u01b0 m\u1ee5c n\u00e0y.",
    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
    "API Token": "API Token",
    "API token is copied to the clipboard.": "API token is copied to the clipboard.",
    "About Us": "Li\u00ean h\u1ec7",
    "Abuse Content": "Abuse Content",
    "Abuse Reports": "Abuse Reports",
    "Abuse Type": "Abuse Type",
    "Abuse report added": "Abuse report added",
    "Accept": "Accept",
    "Accepted": "Accepted",
    "Accepted at": "Accepted at",
    "Accepter": "Accepter",
    "Access Log": "L\u1ecbch s\u1eed truy c\u1eadp",
    "Accurate to minute": "Accurate to minute",
    "Action": "Action",
    "Actions": "Actions",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email",
    "Activated": "Activated",
    "Activated Users": "Activated Users",
    "Active": "\u0110\u00e3 k\u00edch ho\u1ea1t",
    "Active Users": "Ng\u01b0\u1eddi d\u00f9ng \u0111\u00e3 k\u00edch ho\u1ea1t",
    "Activities": "C\u00e1c ho\u1ea1t \u0111\u1ed9ng",
    "Add": "Add",
    "Add Admin": "Add Admin",
    "Add Library": "Th\u00eam th\u01b0 vi\u1ec7n",
    "Add Member": "Add Member",
    "Add Organization": "Add Organization",
    "Add Terms and Conditions": "Add Terms and Conditions",
    "Add User": "Add User",
    "Add Wiki": "Add Wiki",
    "Add admin": "Th\u00eam Admin",
    "Add auto expiration": "Th\u00eam h\u1ebft h\u1ea1n t\u1ef1 \u0111\u1ed9ng",
    "Add cover": "Add cover",
    "Add custom permission": "Add custom permission",
    "Add filter": "Th\u00eam l\u1ecdc",
    "Add group": "Add group",
    "Add group member": "Add group member",
    "Add icon": "Add icon",
    "Add institution": "Add institution",
    "Add members": "Th\u00eam th\u00e0nh vi\u00ean",
    "Add new notification": "Th\u00eam th\u00f4ng b\u00e1o m\u1edbi",
    "Add option": "Add option",
    "Add password protection": "Th\u00eam b\u1ea3o m\u1eadt m\u1eadt kh\u1ea9u",
    "Add permission": "Add permission",
    "Add sort": "Th\u00eam s\u1eafp x\u1ebfp",
    "Add user": "Th\u00eam ng\u01b0\u1eddi d\u00f9ng",
    "Add view": "Add view",
    "Added": "\u0110\u00e3 th\u00eam",
    "Added user {user}": "Added user {user}",
    "Admin": "Admin",
    "Admin Login Logs": "Admin Login Logs",
    "Admin Operation Logs": "Admin Operation Logs",
    "Admin access": "Admin access",
    "Admins": "Admins",
    "Advanced": "Advanced",
    "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.": "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.",
    "All": "T\u1ea5t c\u1ea3",
    "All Groups": "T\u1ea5t c\u1ea3 Group",
    "All Notifications": "T\u1ea5t c\u1ea3 th\u00f4ng b\u00e1o",
    "All Public Links": "All Public Links",
    "All comments": "T\u1ea5t c\u1ea3 b\u00ecnh lu\u1eadn",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.",
    "An integer that is greater than 0 or equal to -2.": "An integer that is greater than 0 or equal to -2.",
    "An integer that is greater than or equal to 0.": "An integer that is greater than or equal to 0.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "Li\u00ean k\u1ebft n\u1ed9i b\u1ed9 l\u00e0 m\u1ed9t li\u00ean k\u1ebft \u0111\u1ebfn m\u1ed9t v\u1ecb tr\u00ed c\u1ee5 th\u1ec3 trong t\u1ec7p ho\u1eb7c trang web. N\u00f3 cho ph\u00e9p ng\u01b0\u1eddi d\u00f9ng nh\u1ea5p v\u00e0o li\u00ean k\u1ebft v\u00e0 di chuy\u1ec3n \u0111\u1ebfn v\u1ecb tr\u00ed \u0111\u00f3 m\u00e0 kh\u00f4ng c\u1ea7n quay l\u1ea1i trang web ban \u0111\u1ea7u.",
    "And": "V\u00e0",
    "Anonymous User": "Anonymous User",
    "Another property has this property type": "Another property has this property type",
    "Another user is editing this file!": "Another user is editing this file!",
    "Anyone with the link": "Anyone with the link",
    "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
    "Are you sure to delete ": "Are you sure to delete ",
    "Are you sure to delete this comment?": "B\u1ea1n c\u00f3 ch\u1eafc ch\u1eafn mu\u1ed1n x\u00f3a b\u00ecnh lu\u1eadn n\u00e0y kh\u00f4ng?",
    "Are you sure to delete this reply?": "B\u1ea1n c\u00f3 ch\u1eafc ch\u1eafn mu\u1ed1n x\u00f3a tr\u1ea3 l\u1eddi n\u00e0y kh\u00f4ng?",
    "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
    "Are you sure you want to clear trash?": "B\u1ea1n c\u00f3 ch\u1eafc mu\u1ed1n l\u00e0m s\u1ea1ch th\u00f9ng r\u00e1c?",
    "Are you sure you want to delete": "Are you sure you want to delete",
    "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
    "Are you sure you want to delete the notification ?": "Are you sure you want to delete the notification ?",
    "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
    "Are you sure you want to delete the selected user(s) ?": "Are you sure you want to delete the selected user(s) ?",
    "Are you sure you want to delete this page?": "B\u1ea1n c\u00f3 ch\u1eafc b\u1ea1n mu\u1ed1n x\u00f3a trang n\u00e0y",
    "Are you sure you want to delete {placeholder} ?": "Are you sure you want to delete {placeholder} ?",
    "Are you sure you want to delete {placeholder} completely?": "Are you sure you want to delete {placeholder} completely?",
    "Are you sure you want to disconnect?": "Are you sure you want to disconnect?",
    "Are you sure you want to remove {placeholder} ?": "Are you sure you want to remove {placeholder} ?",
    "Are you sure you want to reset the password of {placeholder} ?": "Are you sure you want to reset the password of {placeholder} ?",
    "Are you sure you want to restore this library?": "B\u1ea1n c\u00f3 mu\u1ed1n kh\u00f4i ph\u1ee5c th\u01b0 vi\u1ec7n n\u00e0y?",
    "Are you sure you want to restore {placeholder}?": "Are you sure you want to restore {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "Are you sure you want to revoke the admin permission of {placeholder} ?",
    "Are you sure you want to set {placeholder} as Admin?": "Are you sure you want to set {placeholder} as Admin?",
    "Are you sure you want to set {user_placeholder} inactive?": "Are you sure you want to set {user_placeholder} inactive?",
    "Are you sure you want to unlink this device?": "Are you sure you want to unlink this device?",
    "At server": "At server",
    "Audio": "Audio",
    "Auth Token created": "Auth Token created",
    "Auth Token deleted": "Auth Token deleted",
    "Auto deletion": "Auto deletion",
    "Automatically delete files that are not modified within certain days:": "Automatically delete files that are not modified within certain days:",
    "Avatar": "H\u00ecnh \u0111\u1ea1i di\u1ec7n",
    "Avatar updated": "Avatar updated",
    "Avatar:": "Avatar:",
    "Back": "Back",
    "Basic": "Basic",
    "Bell Icon": "Bell Icon",
    "Besides Write permission, user can also share the library.": "Besides Write permission, user can also share the library.",
    "Branding": "Branding",
    "By day": "By day",
    "By month": "By month",
    "By name ascending": "By name ascending",
    "By name descending": "By name descending",
    "By quarter": "By quarter",
    "By size ascending": "By size ascending",
    "By size descending": "By size descending",
    "By time ascending": "By time ascending",
    "By time descending": "By time descending",
    "By week": "By week",
    "By year": "By year",
    "Can not copy folder %(src)s to its subfolder %(des)s": "Can not copy folder %(src)s to its subfolder %(des)s",
    "Can not move folder %(src)s to its subfolder %(des)s": "Can not move folder %(src)s to its subfolder %(des)s",
    "Cancel": "H\u1ee7y",
    "Cancel All": "H\u1ee7y t\u1ea5t c\u1ea3",
    "Cannot move parent page to child page": "Cannot move parent page to child page",
    "Capture information": "Capture information",
    "Capture time": "Capture time",
    "Card": "B\u1ea3n ghi",
    "Certificate": "Certificate",
    "Change": "Thay \u0111\u1ed5i",
    "Change Password": "Thay \u0111\u1ed5i m\u1eadt kh\u1ea9u",
    "Change Password of Library {placeholder}": "Change Password of Library {placeholder}",
    "Change cover": "Change cover",
    "Change group to department": "Change group to department",
    "Change to department": "Change to department",
    "Changes": "Thay \u0111\u1ed5i",
    "Checkbox": "Checkbox",
    "Choose date": "Choose date",
    "Clean": "X\u00f3a",
    "Clean succeeded.": "Clean succeeded.",
    "Cleaned trash": "Cleaned trash",
    "Clear": "X\u00f3a",
    "Clear Trash": "L\u00e0m s\u1ea1ch th\u00f9ng r\u00e1c",
    "Clear files in trash and history\uff1a": "Clear files in trash and history\uff1a",
    "Clear selected": "Clear selected",
    "Close": "\u0110\u00f3ng",
    "Code": "M\u00e3 l\u1ec7nh",
    "Collaborator": "Collaborator",
    "Collaborators": "Ng\u01b0\u1eddi tham gia",
    "Collapse all": "Collapse all",
    "Color space": "Color space",
    "Comment": "B\u00ecnh lu\u1eadn",
    "Comment details": "Chi ti\u1ebft b\u00ecnh lu\u1eadn",
    "Comments": "B\u00ecnh lu\u1eadn",
    "Community Edition": "Phi\u00ean b\u1ea3n Community",
    "Compressed": "Compressed",
    "Configure Seafile": "Configure Seafile",
    "Configure your Identity Provider": "Configure your Identity Provider",
    "Confirm": "X\u00e1c nh\u1eadn",
    "Confirm Password": "X\u00e1c nh\u1eadn m\u1eadt kh\u1ea9u",
    "Confirm password": "Confirm password",
    "Connect": "Connect",
    "Contact Email": "Contact Email",
    "Contact Email:": "Email li\u00ean h\u1ec7:",
    "Contact Information": "Contact Information",
    "Contact information is required.": "Contact information is required.",
    "Content Scan Records": "Content Scan Records",
    "Convert & Export": "Convert & Export",
    "Convert Wiki": "Convert Wiki",
    "Convert to Markdown": "Convert to Markdown",
    "Convert to docx": "Convert to docx",
    "Convert to sdoc": "Convert to sdoc",
    "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
    "Converting, please wait...": "Converting, please wait...",
    "Copied": "\u0110\u00e3 sao ch\u00e9p",
    "Copied link to clipboard": "Copied link to clipboard",
    "Copy": "Sao ch\u00e9p",
    "Copy failed": "Copy failed",
    "Copy link": "Copy link",
    "Copy selected": "Copy selected",
    "Copy selected item(s) to:": "Copy selected item(s) to:",
    "Copy the IdP's certificate and paste it here. The certificate format is as follows:": "Copy the IdP's certificate and paste it here. The certificate format is as follows:",
    "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.": "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.",
    "Copy {num} items": "Copy {num} items",
    "Copy {placeholder} to": "Copy {placeholder} to",
    "Copyright Infringement": "Copyright Infringement",
    "Count": "Count",
    "Cover": "Cover",
    "Create": "T\u1ea1o l\u1eadp",
    "Create At": "T\u1ea1o l\u00fac",
    "Create Group": "Create Group",
    "Create Library": "Create Library",
    "Create Report": "Create Report",
    "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
    "Create a new tag": "T\u1ea1o tag m\u1edbi",
    "Created": "Created",
    "Created At": "Created At",
    "Created Files": "Created Files",
    "Created draft": "Created draft",
    "Created file": "Created file",
    "Created folder": "Created folder",
    "Created group {group_name}": "Created group {group_name}",
    "Created library": "\u0110\u00e3 t\u1ea1o th\u01b0 vi\u1ec7n",
    "Created library {library_name} with {owner} as its owner": "Created library {library_name} with {owner} as its owner",
    "Created time": "Th\u1eddi gian t\u1ea1o",
    "Created {n} files": "Created {n} files",
    "Creator": "Ng\u01b0\u1eddi t\u1ea1o",
    "Current Connected Devices": "Current Connected Devices",
    "Current Library": "Th\u01b0 vi\u1ec7n hi\u1ec7n t\u1ea1i",
    "Current Path: ": "\u0110\u01b0\u1eddng d\u1eabn hi\u1ec7n t\u1ea1i",
    "Current page": "Current page",
    "Current password": "Current password",
    "Current password cannot be blank": "M\u1eadt kh\u1ea9u hi\u1ec7n t\u1ea1i kh\u00f4ng \u0111\u01b0\u1ee3c \u0111\u1ec3 tr\u1ed1ng",
    "Current path: ": "\u0110\u01b0\u1eddng d\u1eabn hi\u1ec7n t\u1ea1i",
    "Custom CSS": "Custom CSS",
    "Custom properties": "Custom properties",
    "Custom sharing permissions": "Custom sharing permissions",
    "Customize URL": "Customize URL",
    "DNS TXT Value": "DNS TXT Value",
    "Date": "Ng\u00e0y",
    "Date Invalid.": "Date Invalid.",
    "Day": "Day",
    "Default": "M\u1eb7c \u0111\u1ecbnh",
    "Delete": "X\u00f3a",
    "Delete Account": "X\u00f3a t\u00e0i kho\u1ea3n",
    "Delete Department": "Delete Department",
    "Delete Expired Invitations": "Delete Expired Invitations",
    "Delete File": "Delete File",
    "Delete Folder": "Delete Folder",
    "Delete Group": "X\u00f3a nh\u00f3m",
    "Delete Library": "X\u00f3a th\u01b0 vei65n",
    "Delete Member": "X\u00f3a th\u00e0nh vi\u00ean",
    "Delete Notification": "X\u00f3a th\u00f4ng b\u00e1o",
    "Delete Password": "Delete Password",
    "Delete T&C": "Delete T&C",
    "Delete User": "X\u00f3a ng\u01b0\u1eddi d\u00f9ng",
    "Delete Users": "Delete Users",
    "Delete WebDAV Password": "Delete WebDAV Password",
    "Delete file": "Delete file",
    "Delete files from this device the next time it comes online.": "Delete files from this device the next time it comes online.",
    "Delete folder": "Delete folder",
    "Delete group": "Delete group",
    "Delete page": "Delete page",
    "Delete property": "Delete property",
    "Delete selected": "Delete selected",
    "Delete share links": "Delete share links",
    "Deleted": "\u0110\u00e3 x\u00f3a",
    "Deleted Libraries": "Deleted Libraries",
    "Deleted Time": "Th\u1eddi gian x\u00f3a",
    "Deleted directories": "X\u00f3a th\u01b0 m\u1ee5c",
    "Deleted draft": "Deleted draft",
    "Deleted file": "Deleted file",
    "Deleted files": "X\u00f3a t\u1eadp tin",
    "Deleted folder": "Deleted folder",
    "Deleted group {group_name}": "Deleted group {group_name}",
    "Deleted library": "X\u00f3a th\u01b0 vi\u1ec7n",
    "Deleted library {library_name}": "Deleted library {library_name}",
    "Deleted option": "Deleted option",
    "Deleted user %s": "Deleted user %s",
    "Deleted user {user}": "Deleted user {user}",
    "Department renamed": "Department renamed",
    "Departments": "Departments",
    "Description": "M\u00f4 t\u1ea3",
    "Description is required": "Y\u00eau c\u1ea7u m\u00f4 t\u1ea3",
    "Desktop": "Desktop",
    "Detail": "Chi ti\u1ebft",
    "Details": "Details",
    "Device": "Device",
    "Device Name": "T\u00ean thi\u1ebft b\u1ecb",
    "Device make": "Device make",
    "Device model": "Device model",
    "Devices": "C\u00e1c thi\u1ebft b\u1ecb",
    "Dimensions": "Dimensions",
    "Direct download link": "Direct download link",
    "Direct download link is copied to the clipboard.": "Direct download link is copied to the clipboard.",
    "Disconnect": "Disconnect",
    "Discussion": "Th\u1ea3o lu\u1eadn",
    "Display files": "Display files",
    "Do not automatically delete files": "Do not automatically delete files",
    "Do you really want to turn off extended properties? Existing properties will all be deleted.": "Do you really want to turn off extended properties? Existing properties will all be deleted.",
    "Document": "Document",
    "Document conversion failed.": "Document conversion failed.",
    "Document keywords": "Document keywords",
    "Domain verified": "Domain verified",
    "Don't ignore": "Don't ignore",
    "Don't keep history": "Don't keep history",
    "Don't replace": "Kh\u00f4ng thay th\u1ebf",
    "Don't send emails": "Don't send emails",
    "Done": "Done",
    "Down": "Xu\u1ed1ng",
    "Download": "T\u1ea3i xu\u1ed1ng",
    "Download and upload": "Download and upload",
    "Duplicate": "Duplicate",
    "Duplicate page": "Duplicate page",
    "Edit": "Ch\u1ec9nh s\u1eeda",
    "Edit format settings": "Edit format settings",
    "Edit labels": "Edit labels",
    "Edit metadata properties": "Edit metadata properties",
    "Edit multiple select": "Edit multiple select",
    "Edit on cloud and download": "Edit on cloud and download",
    "Edit on cloud only": "Edit on cloud only",
    "Edit permission": "Edit permission",
    "Edit single select": "Edit single select",
    "Edit succeeded": "Ch\u1ec9nh s\u1eeda th\u00e0nh c\u00f4ng",
    "Edit succeeded.": "Edit succeeded.",
    "Email": "Email",
    "Email Domain": "Email Domain",
    "Email Notification": "Email Notification",
    "Email is invalid.": "Email is invalid.",
    "Email notification updated": "Email notification updated",
    "Emails": "Emails",
    "Emails, separated by ','": "Emails, separated by ','",
    "Emojis": "Emojis",
    "Empty": "Tr\u1ed1ng",
    "Enable extended properties": "Enable extended properties",
    "Enable face recognition to identify people in your photos.": "Enable face recognition to identify people in your photos.",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.",
    "Enable two factor authentication": "Enable two factor authentication",
    "Enable users to share libraries to any groups in the system.": "Enable users to share libraries to any groups in the system.",
    "Encrypt": "M\u00e3 h\u00f3a",
    "Encrypted library": "Encrypted library",
    "End date": "End date",
    "Enter characters to start searching": "Enter characters to start searching",
    "Error": "L\u1ed7i",
    "Errors": "Errors",
    "European": "European",
    "Exact date": "Exact date",
    "Exit Institution Admin": "Exit Institution Admin",
    "Exit Organization Admin": "Exit Organization Admin",
    "Exit System Admin": "Tho\u00e1t kh\u1ecfi h\u1ec7 th\u1ed1ng qu\u1ea3n l\u00fd",
    "Expand all": "Expand all",
    "Expiration": "H\u1ebft h\u1ea1n",
    "Expiration days": "Expiration days",
    "Expiration time": "Expiration time",
    "Expired": "Expired",
    "Expired at": "Expired at",
    "Export": "Export",
    "Export Excel": "Xu\u1ea5t file Excel",
    "Export as docx": "Export as docx",
    "Export as zip": "Export as zip",
    "Export tags": "Export tags",
    "Exporting": "Exporting",
    "Exporting...": "Exporting...",
    "Exposure time": "Exposure time",
    "Extended properties": "Extended properties",
    "Extension Prompts": "Extension Prompts",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Extensions of text files that can be online previewed, each suffix is separated by a comma.",
    "Extract file detail": "Extract file detail",
    "Extract file details": "Extract file details",
    "F number": "F number",
    "Face recognition": "Face recognition",
    "Failed": "Failed",
    "Failed imported options": "Failed imported options",
    "Failed to convert {name}.": "Failed to convert {name}.",
    "Failed to copy %(name)s": "Failed to copy %(name)s",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Failed to copy %(name)s and %(amount)s other item(s).",
    "Failed to copy %(name)s.": "Failed to copy %(name)s.",
    "Failed to copy files to another library.": "Failed to copy files to another library.",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Failed to delete %(virus_file) from library %(library): %(error_msg)",
    "Failed to delete property": "Failed to delete property",
    "Failed to delete records": "Failed to delete records",
    "Failed to delete {name}": "Failed to delete {name}",
    "Failed to delete {name} and {n} other items.": "Failed to delete {name} and {n} other items.",
    "Failed to delete {name}.": "Failed to delete {name}.",
    "Failed to download. The total size of the files exceeded the limit.": "Failed to download. The total size of the files exceeded the limit.",
    "Failed to duplicate page": "Failed to duplicate page",
    "Failed to export. Please check whether the size of table attachments exceeds the limit.": "Failed to export. Please check whether the size of table attachments exceeds the limit.",
    "Failed to extract file details": "Failed to extract file details",
    "Failed to generate description": "Failed to generate description",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Failed to ignore %(virus_file) from library %(library): %(error_msg)",
    "Failed to insert property": "Failed to insert property",
    "Failed to modify filter": "Failed to modify filter",
    "Failed to modify group": "Failed to modify group",
    "Failed to modify hidden properties": "Failed to modify hidden properties",
    "Failed to modify people name": "Failed to modify people name",
    "Failed to modify property data": "Failed to modify property data",
    "Failed to modify property order": "Failed to modify property order",
    "Failed to modify records": "Failed to modify records",
    "Failed to modify sort": "Failed to modify sort",
    "Failed to move %(name)s and %(amount)s other item(s).": "Failed to move %(name)s and %(amount)s other item(s).",
    "Failed to move %(name)s.": "Failed to move %(name)s.",
    "Failed to move files to another library.": "Failed to move files to another library.",
    "Failed to move {name}.": "Failed to move {name}.",
    "Failed to rename property": "Failed to rename property",
    "Failed to restore records": "Failed to restore records",
    "Failed to restore {name}": "Failed to restore {name}",
    "Failed to restore {name} and {n} other items": "Failed to restore {name} and {n} other items",
    "Failed to save": "Failed to save",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Failed to send to {email_placeholder}: {errorMsg_placeholder}",
    "Failed to unshare {name}": "Failed to unshare {name}",
    "Failed to upload {file_name}.": "Failed to upload {file_name}.",
    "Failed. Please check the network.": "Th\u1ea5t b\u1ea1i. Vui l\u00f2ng ki\u1ec3m tra l\u1ea1i network.",
    "File": "T\u1eadp tin",
    "File Access": "File Access",
    "File Operations": "File Operations",
    "File Update": "File Update",
    "File Upload": "File Upload",
    "File Uploading...": "\u0110ang t\u1ea3i d\u1eef li\u1ec7u",
    "File already exists.": "File already exists.",
    "File collaborators": "File collaborators",
    "File details": "File details",
    "File download is disabled: the share link traffic of owner is used up.": "Kh\u00f4ng th\u1ec3 t\u1ea3i xu\u1ed1ng: \u0111\u00e3 d\u00f9ng h\u1ebft b\u0103ng th\u00f4ng chia s\u1ebb",
    "File expire time": "File expire time",
    "File extension white list": "File extension white list",
    "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.": "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.",
    "File extensions can only be {placeholder}.": "File extensions can only be {placeholder}.",
    "File is locked by others.": "File is locked by others.",
    "File name": "File name",
    "File owner": "File owner",
    "File reviewer": "File reviewer",
    "File size is too large.": "File size is too large.",
    "File status": "File status",
    "File too large": "File too large",
    "File type": "File type",
    "Files": "T\u1eadp tin",
    "Files and folders": "Files and folders",
    "Filter": "L\u1ecdc",
    "Filters": "Filters",
    "Find a tag": "Find a tag",
    "Find modifiers": "Find modifiers",
    "Focal length": "Focal length",
    "Folder": "Th\u01b0 m\u1ee5c",
    "Folder Permission": "Folder Permission",
    "Folder does not exist.": "Folder does not exist.",
    "Folders": "Th\u01b0 m\u1ee5c",
    "Force user to change password when account is newly added or reset by admin": "Force user to change password when account is newly added or reset by admin",
    "Force user to use a strong password when sign up or change password.": "Force user to use a strong password when sign up or change password.",
    "Format": "Format",
    "Freeze Document": "Freeze Document",
    "Freeze user account when failed login attempts exceed limit.": "Freeze user account when failed login attempts exceed limit.",
    "Frozen by {name}": "Frozen by {name}",
    "Full screen": "Hi\u1ec3n th\u1ecb to\u00e0n m\u00e0n h\u00ecnh",
    "Gallery": "Gallery",
    "General information": "General information",
    "Generate": "Kh\u1edfi t\u1ea1o",
    "Generate Link": "Generate Link",
    "Generate description": "Generate description",
    "Generate links in batch": "Generate links in batch",
    "Generate share link": "Generate share link",
    "Germany Russia etc": "Germany Russia etc",
    "Global Address Book": "Global Address Book",
    "Greater than or equal to {minDays_placeholder} days": "Greater than or equal to {minDays_placeholder} days",
    "Grid view": "Grid view",
    "Group": "Group",
    "Group Permission": "Group Permission",
    "Group Shares": "Group Shares",
    "Group by": "Group by",
    "Group members": "Group members",
    "Grouped by 1 property": "Grouped by 1 property",
    "Groups": "H\u1ed9i Nh\u00f3m",
    "Guest": "T\u00e0i kho\u1ea3n Kh\u00e1ch",
    "Handled": "Handled",
    "Help": "Tr\u1ee3 gi\u00fap",
    "Hide": "\u1ea8n",
    "Hide all": "\u1ea8n t\u1ea5t c\u1ea3",
    "Hide properties": "Hide properties",
    "History": "L\u1ecbch s\u1eed",
    "History Versions": "History Versions",
    "IP": "\u0110\u1ecba ch\u1ec9 IP",
    "ISO": "ISO",
    "If notifications have not been read within one hour, they will be sent to your mailbox.": "If notifications have not been read within one hour, they will be sent to your mailbox.",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.",
    "Ignore": "Ignore",
    "Ignored": "Ignored",
    "Import Users": "Import Users",
    "Import members": "Import members",
    "Import members from a .xlsx file": "Import members from a .xlsx file",
    "Import options": "Import options",
    "Import sdoc": "Import sdoc",
    "Import tags": "Import tags",
    "Import users": "Nh\u1eadp ng\u01b0\u1eddi d\u00f9ng",
    "Import users from a .xlsx file": "Import users from a .xlsx file",
    "In progress": "In progress",
    "In review": "In review",
    "Inactive": "Ch\u01b0a k\u00edch ho\u1ea1t",
    "Info": "Th\u00f4ng tin",
    "Institution Admin": "Institution Admin",
    "Internal Link": "Internal Link",
    "Internal Server Error": "Internal Server Error",
    "Internal link has been copied to clipboard": " Sao ch\u00e9p li\u00ean k\u1ebft n\u1ed9i b\u1ed9",
    "Invalid destination path": "\u0110\u01b0\u1eddng d\u1eabn kh\u00f4ng h\u1ee3p l\u1ec7",
    "Invalid filename.": "Invalid filename.",
    "Invalid filter": "L\u1ecdc kh\u00f4ng h\u1ee3p l\u1ec7",
    "Invalid month, should be yyyymm.": "Invalid month, should be yyyymm.",
    "Invalid regular expression": "Invalid regular expression",
    "Invisible": "Invisible",
    "Invitations": "Invitations",
    "Invite Guest": "Invite Guest",
    "Invite Time": "Invite Time",
    "Invite users": "Invite users",
    "Invited at": "Invited at",
    "Inviter": "Inviter",
    "Is expired": "Is expired",
    "It is required.": "\u0110i\u1ec1u n\u00e0y \u0111\u01b0\u1ee3c y\u00eau c\u1ea7u",
    "It may take some time, please wait.": "It may take some time, please wait.",
    "Keep full history": "Keep full history",
    "Keep sharing": "Keep sharing",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(imported)",
    "Label": "Label",
    "Label Current State": "Label Current State",
    "Labels": "Labels",
    "Language": "Ng\u00f4n ng\u1eef",
    "Language Setting": "C\u00e0i \u0111\u1eb7t ng\u00f4n ng\u1eef",
    "Last Access": "Truy c\u1eadp l\u1ea7n cu\u1ed1i",
    "Last Login": "L\u1ea7n \u0111\u0103ng nh\u1eadp cu\u1ed1i",
    "Last Update": "C\u1eadp nh\u1eadt",
    "Last modification": "L\u1ea7n s\u1eeda cu\u1ed1i",
    "Last modified by": "Last modified by",
    "Last modified time": "Last modified time",
    "Last modifier": "Last modifier",
    "Leave": "Leave",
    "Leave Group": "Leave Group",
    "Leave Share": "Leave Share",
    "Leave group": "R\u1eddi Group",
    "Leave this page? The system may not save your changes.": "Leave this page? The system may not save your changes.",
    "Less than or equal to {maxDays_placeholder} days": "Less than or equal to {maxDays_placeholder} days",
    "Libraries": "Th\u01b0 vi\u1ec7n",
    "Library": "Th\u01b0 vi\u1ec7n",
    "Library Type": "Library Type",
    "Library does not exist": "Th\u01b0 vi\u1ec7n kh\u00f4ng t\u1ed3n t\u1ea1i",
    "Limits": "Gi\u1edbi h\u1ea1n",
    "Link": "Li\u00ean k\u1ebft",
    "Link has been copied to clipboard": "Link has been copied to clipboard",
    "Linked Devices": "Linked Devices",
    "Links": "Links",
    "List view": "List view",
    "List your account in global address book, so that others can find you by typing your name.": "List your account in global address book, so that others can find you by typing your name.",
    "Load all": "Load all",
    "Loading": "Loading",
    "Loading...": "\u0110ang t\u1ea3i...",
    "Location": "V\u1ecb tr\u00ed",
    "Lock": "Kh\u00f3a",
    "Log out": "\u0110\u0103ng xu\u1ea5t",
    "Login": "Login",
    "Login ID": "Login ID",
    "Logo updated": "Logo updated",
    "Logs": "Logs",
    "Long text": "Long text",
    "Manage group members": "Manage group members",
    "Manage members": "Manage members",
    "Mark all as read": "\u0110\u00e1nh d\u1ea5u t\u1ea5t c\u1ea3 l\u00e0 \u0111\u00e3 \u0111\u1ecdc",
    "Mark all read": "\u0110\u00e1nh d\u1ea5u \u0111\u00e3 \u0111\u1ecdc",
    "Mark as resolved": "\u0110\u00e1nh d\u1ea5u \u0111\u00e3 gi\u1ea3i quy\u1ebft",
    "Max": "Max",
    "Max number of members": "Max number of members",
    "Member": "Member",
    "Members": "Th\u00e0nh vi\u00ean",
    "Message": "Tin nh\u1eafn",
    "Message (optional):": "L\u1eddi nh\u1eafn (t\u00f9y ch\u1ecdn)",
    "Migrate User": "Migrate User",
    "Mobile": "Mobile",
    "Modification Details": "Chi ti\u1ebft thay \u0111\u1ed5i",
    "Modified": "\u0110\u00e3 s\u1eeda \u0111\u1ed5i",
    "Modified by": "Modified by",
    "Modified by:": "Modified by:",
    "Modified files": "S\u1eeda \u0111\u1ed5i t\u1eadp tin",
    "Modifier": "\u0110i\u1ec1u ch\u1ec9nh",
    "Modify": "Modify",
    "Modify includes modify file, move/rename file and folder": "Modify includes modify file, move/rename file and folder",
    "Modify name": "Modify name",
    "Month": "Month",
    "Month:": "Th\u00e1ng:",
    "Monthly User Traffic": "Monthly User Traffic",
    "More": "Th\u00eam",
    "More operations": "More operations",
    "Move": "Di chuy\u1ec3n",
    "Move selected item(s) to:": "Move selected item(s) to:",
    "Move {num} items": "Move {num} items",
    "Move {placeholder} to": "Move {placeholder} to",
    "Moved file": "Moved file",
    "Moved folder": "Moved folder",
    "Multiple select": "Multiple select",
    "My Libraries": "My Libraries",
    "My Wikis": "My Wikis",
    "Name": "T\u00ean",
    "Name already exists": "Name already exists",
    "Name cannot be double dots": "Name cannot be double dots",
    "Name cannot be empty": "Name cannot be empty",
    "Name cannot contain backslash": "Name cannot contain backslash",
    "Name cannot contain backtick": "Name cannot contain backtick",
    "Name cannot contain curly braces": "Name cannot contain curly braces",
    "Name cannot contain dots": "Name cannot contain dots",
    "Name cannot contain slash": "Name cannot contain slash",
    "Name is required": "Y\u00eau c\u1ea7u t\u00ean",
    "Name is required.": "Y\u00eau c\u1ea7u t\u00ean.",
    "Name or ID": "Name or ID",
    "Name should be string": "Name should be string",
    "Name should not include '/'.": "Name should not include '/'.",
    "Name updated": "Name updated",
    "Name(optional)": "Name(optional)",
    "Network error": "Network error",
    "New": "M\u1edbi",
    "New Department": "New Department",
    "New Department Library": "New Department Library",
    "New Excel File": "New Excel File",
    "New File": "T\u1eadp tin m\u1edbi",
    "New Folder": "Th\u01b0 m\u1ee5c m\u1edbi",
    "New Group": "T\u1ea1o Group m\u1edbi",
    "New Library": "T\u1ea1o th\u01b0 vi\u1ec7n m\u1edbi",
    "New Markdown File": "New Markdown File",
    "New Password": "M\u1eadt kh\u1ea9u m\u1edbi",
    "New Password Again": "Nh\u1eadp l\u1ea1i m\u1eadt kh\u1ea9u m\u1edbi",
    "New PowerPoint File": "New PowerPoint File",
    "New SeaDoc File": "New SeaDoc File",
    "New Sub-department": "New Sub-department",
    "New Word File": "New Word File",
    "New directories": "Th\u01b0 m\u1ee5c m\u1edbi",
    "New file name": "New file name",
    "New files": "T\u1eadp tin m\u1edbi",
    "New folder name": "New folder name",
    "New page": "Trang m\u1edbi",
    "New password": "M\u1eadt kh\u1ea9u m\u1edbi",
    "New password cannot be the same as old password": "New password cannot be the same as old password",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.",
    "New password is too short": "M\u1eadt kh\u1ea9u m\u1edbi qu\u00e1 ng\u1eafn",
    "New passwords don't match": "M\u1eadt kh\u1ea9u m\u1edbi kh\u00f4ng tr\u00f9ng kh\u1edbp",
    "New view": "New view",
    "Next": "Ti\u1ebfp theo",
    "Next modification": "L\u1ea7n s\u1eeda ti\u1ebfp theo",
    "No Admin login logs": "No Admin login logs",
    "No Admin operation logs": "No Admin operation logs",
    "No Wikis": "No Wikis",
    "No changes": "Kh\u00f4ng c\u00f3 thay \u0111\u1ed5i",
    "No collaborators": "No collaborators",
    "No collaborators available": "No collaborators available",
    "No comment yet.": "Ch\u01b0a c\u00f3 b\u00ecnh lu\u1eadn",
    "No connected devices": "No connected devices",
    "No deleted libraries": "No deleted libraries",
    "No favorites": "No favorites",
    "No file": "No file",
    "No file access logs": "No file access logs",
    "No file update logs": "No file update logs",
    "No filters": "Ch\u01b0a c\u00f3 l\u1ecdc",
    "No folders shared": "No folders shared",
    "No groupings applied to this view.": "No groupings applied to this view.",
    "No groups": "No groups",
    "No guest invitations": "No guest invitations",
    "No invitations": "No invitations",
    "No libraries": "No libraries",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.",
    "No libraries have been shared with you": "No libraries have been shared with you",
    "No libraries have been shared with you from other servers.": "No libraries have been shared with you from other servers.",
    "No libraries shared": "No libraries shared",
    "No libraries shared with this group": "No libraries shared with this group",
    "No linked devices": "No linked devices",
    "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "No login logs": "No login logs",
    "No members": "No members",
    "No more activities": "No more activities",
    "No notifications": "No notifications",
    "No option": "No option",
    "No options": "No options",
    "No options available": "No options available",
    "No permission logs": "No permission logs",
    "No properties available to be hidden": "No properties available to be hidden",
    "No record": "No record",
    "No result": "Kh\u00f4ng t\u00ecm th\u1ea5y k\u1ebft qu\u1ea3",
    "No results": "Kh\u00f4ng c\u00f3 k\u1ebft qu\u1ea3",
    "No results matching": "No results matching",
    "No share links": "No share links",
    "No sorts": "Kh\u00f4ng c\u00f3 s\u1eafp x\u1ebfp",
    "No sync errors": "No sync errors",
    "No tags": "Kh\u00f4ng c\u00f3 th\u1ebb",
    "No terms and conditions": "No terms and conditions",
    "No upload links": "No upload links",
    "No version history": "No version history",
    "None": "None",
    "Not allow user to clean library trash": "Not allow user to clean library trash",
    "Not allow user to create encrypted libraries": "Not allow user to create encrypted libraries",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.",
    "Notification Detail": "Chi ti\u1ebft th\u00f4ng b\u00e1o",
    "Notifications": "Th\u00f4ng b\u00e1o",
    "Notifications of file changes": "Notifications of file changes",
    "Number": "Number",
    "Number of days ago": "Number of days ago",
    "Number of days from now": "Number of days from now",
    "Number of days that keep user sign in.": "Number of days that keep user sign in.",
    "Number of groups": "S\u1ed0 l\u01b0\u1ee3ng nh\u00f3m",
    "Number of links": "Number of links",
    "Number of members": "S\u1ed1 l\u01b0\u1ee3ng th\u00e0nh vi\u00ean",
    "Off": "Off",
    "Old Password": "M\u1eadt kh\u1ea9u c\u0169",
    "Old Wikis": "Old Wikis",
    "On": "On",
    "One month ago": "One month ago",
    "One month from now": "One month from now",
    "One week ago": "One week ago",
    "One week from now": "One week from now",
    "Online Preview": "Online Preview",
    "Online Read-Only": "Online Read-Only",
    "Online Read-Only folder": "Online Read-Only folder",
    "Online Read-Only library": "Online Read-Only library",
    "Online Read-Write": "Online Read-Write",
    "Online Read-Write folder": "Online Read-Write folder",
    "Online Read-Write library": "Online Read-Write library",
    "Online view is not applicable to this file format": "Online view is not applicable to this file format",
    "Only Show": "Only Show",
    "Only files": "Only files",
    "Only folders": "Only folders",
    "Only keep a period of history:": "Only keep a period of history:",
    "Only pictures": "Only pictures",
    "Only videos": "Only videos",
    "Open file": "Open file",
    "Open file in new tab": "Open file in new tab",
    "Open folder": "Open folder",
    "Open folder in new tab": "Open folder in new tab",
    "Open in new tab": "Open in new tab",
    "Open parent folder": "M\u1edf th\u01b0 m\u1ee5c cha",
    "Open via Client": "Open via Client",
    "Operation": "Operation",
    "Operation succeeded.": "Thao t\u00e1c th\u00e0nh c\u00f4ng",
    "Operations": "T\u00ednh n\u0103ng",
    "Optional": "Optional",
    "Options imported": "Options imported",
    "Or": "Ho\u1eb7c",
    "Organization": "T\u1ed5 ch\u1ee9c",
    "Organization Admin": "Organization Admin",
    "Organizations": "T\u1ed5 ch\u1ee9c",
    "Original path": "Original path",
    "Other": "Other",
    "Other Libraries": "Th\u01b0 vi\u1ec7n kh\u00e1c",
    "Others": "Others",
    "Out of quota.": "Out of quota.",
    "Outdated": "Outdated",
    "Outline": "Danh s\u00e1ch",
    "Owned Libraries": "Owned Libraries",
    "Owner": "Owner",
    "Owner can use admin panel in an organization, must be a new account.": "Owner can use admin panel in an organization, must be a new account.",
    "Packaging...": "Packaging...",
    "Page name": "Page name",
    "Pages": "Trang",
    "Parent folder": "Parent folder",
    "Password": "M\u1eadt kh\u1ea9u",
    "Password again": "Nh\u1eadp l\u1ea1i m\u1eadt kh\u1ea9u",
    "Password cannot be blank": "M\u1eadt kh\u1ea9u kh\u00f4ng \u0111\u01b0\u1ee3c \u0111\u1ec3 tr\u1ed1ng",
    "Password is too short": "M\u1eadt kh\u1ea9u qu\u00e1 ng\u1eafn",
    "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols": "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols",
    "Password removed": "Password removed",
    "Password reset": "Password reset",
    "Password set": "Password set",
    "Password strength": "Password strength",
    "Password updated": "Password updated",
    "Passwords do not match.": "Passwords do not match.",
    "Passwords don't match": "M\u1eadt kh\u1ea9u kh\u00f4ng tr\u00f9ng kh\u1edbp",
    "Path": "Path",
    "Per 4 hours": "Per 4 hours",
    "Per day": "Per day",
    "Per hour": "Per hour",
    "Per week": "Per week",
    "Permission": "Quy\u1ec1n h\u1ea1n",
    "Permission denied": "Kh\u00f4ng c\u00f3 quy\u1ec1n",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "Permission denied. Please try {placeholder-left}login again.{placeholder-right}",
    "Permission name": "Permission name",
    "Person image": "Person image",
    "Picture": "Picture",
    "Pictures and videos": "Pictures and videos",
    "Platform": "N\u1ec1n t\u1ea3ng",
    "Please check the network.": "Vui l\u00f2ng ki\u1ec3m tra l\u1ea1i network.",
    "Please choose a .xlsx file.": "Please choose a .xlsx file.",
    "Please choose an image file.": "Please choose an image file.",
    "Please enter 1 or more character": "Vui l\u00f2ng th\u00eam k\u00fd t\u1ef1",
    "Please enter a new password": "Please enter a new password",
    "Please enter a non-negative integer": "Vui l\u00f2ng nh\u1eadp s\u1ed1 kh\u00f4ng \u00e2m",
    "Please enter a password.": "Please enter a password.",
    "Please enter a positive integer": "Please enter a positive integer",
    "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
    "Please enter an integer not bigger than {max_number} as number of links.": "Please enter an integer not bigger than {max_number} as number of links.",
    "Please enter days": "Vui l\u00f2ng nh\u1eadp s\u1ed1 ng\u00e0y",
    "Please enter password": "Vui l\u00f2ng nh\u1eadp m\u1eadt kh\u1ea9u",
    "Please enter the new password again": "Vui l\u00f2ng nh\u1eadp m\u1eadt kh\u1ea9u m\u1edbi l\u1ea7n n\u1eefa",
    "Please enter the old password": "Vui l\u00f2ng nh\u1eadp m\u1eadt kh\u1ea9u c\u0169",
    "Please enter the password again": "Vui l\u00f2ng nh\u1eadp l\u1ea1i m\u1eadt kh\u1ea9u",
    "Please input at least an email.": "Vui l\u00f2ng ch\u1ecdn \u00edt nh\u1ea5t m\u1ed9t \u0111\u1ecba ch\u1ec9 email",
    "Please select a file": "Please select a file",
    "Please select a library to share.": "Please select a library to share.",
    "Please select an expiration time": "Please select an expiration time",
    "Please upload no more than {maxFiles} files at a time.": "Please upload no more than {maxFiles} files at a time.",
    "Preset hide properties": "Preset hide properties",
    "Preview and download": "Xem tr\u01b0\u1edbc v\u00e0 t\u1ea3i xu\u1ed1ng",
    "Preview online": "Preview online",
    "Preview only": "Ch\u1ec9 xem tr\u01b0\u1edbc",
    "Previous": "Tr\u01b0\u1edbc",
    "Print": "In",
    "Professional Edition": "Phi\u00ean b\u1ea3n Professional",
    "Profile": "H\u1ed3 S\u01a1 C\u00e1 Nh\u00e2n",
    "Profile Setting": "C\u00e0i \u0111\u1eb7t h\u1ed3 s\u01a1 c\u00e1 nh\u00e2n",
    "Properties": "Properties",
    "Property name": "Property name",
    "Publish": "Xu\u1ea5t b\u1ea3n",
    "Publish Wiki": "Publish Wiki",
    "Published": "Xu\u1ea5t b\u1ea3n",
    "Quota": "Quota",
    "Quota is invalid.": "Quota is invalid.",
    "Rate": "Rate",
    "Read-Only": "Ch\u1ec9 xem",
    "Read-Only folder": "Read-Only folder",
    "Read-Only library": "Read-Only library",
    "Read-Write": "Xem - \u0110i\u1ec1u ch\u1ec9nh",
    "Read-Write folder": "Read-Write folder",
    "Read-Write library": "Read-Write library",
    "Really want to delete this group?": "Really want to delete this group?",
    "Really want to delete your account?": "B\u1ea1n c\u00f3 th\u1eadt s\u1ef1 mu\u1ed1n x\u00f3a t\u00e0i kho\u1ea3n c\u1ee7a b\u1ea1n?",
    "Really want to leave this group?": "Really want to leave this group?",
    "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
    "Refresh": "L\u00e0m m\u1edbi",
    "Remove": "Lo\u1ea1i b\u1ecf",
    "Rename": "\u0110\u1ed5i t\u00ean",
    "Rename Department": "Rename Department",
    "Rename File": "\u0110\u1ed5i t\u00ean file",
    "Rename Folder": "Rename Folder",
    "Rename Group": "Rename Group",
    "Rename Wiki": "Rename Wiki",
    "Rename file": "Rename file",
    "Rename folder": "Rename folder",
    "Rename group to": "Rename group to",
    "Rename property": "Rename property",
    "Renamed file": "Renamed file",
    "Renamed folder": "Renamed folder",
    "Renamed library": "Renamed library",
    "Renamed or Moved files": "\u0110\u1ed5i t\u00ean ho\u1eb7c chuy\u1ec3n t\u1eadp tin",
    "Renaming {name} failed": "Renaming {name} failed",
    "Replace": "Thay th\u1ebf",
    "Replace file {filename}?": "Replace file {filename}?",
    "Replacing it will overwrite its content.": "Thay th\u1ebf s\u1ebd ghi \u0111\u00e8 n\u1ed9i dung.",
    "Report Abuse": "Report Abuse",
    "Reporter": "Reporter",
    "Reports": "Reports",
    "Required at least three letters.": "Required at least three letters.",
    "Reset": "Reset",
    "Reset Password": "\u0110\u00e3 \u0111\u1ed5i M\u1eadt kh\u1ea9u",
    "Reset WebDAV Password": "Reset WebDAV Password",
    "Reset library password": "Reset library password",
    "ResetPwd": "Thay \u0111\u1ed5i m\u1eadt kh\u1ea9u",
    "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
    "Resolved comments": "B\u00ecnh lu\u1eadn \u0111\u00e3 gi\u1ea3i quy\u1ebft",
    "Restore": "Kh\u00f4i ph\u1ee5c",
    "Restore Library": "Kh\u00f4i ph\u1ee5c th\u01b0 vi\u1ec7n",
    "Restored file": "Restored file",
    "Restored folder": "Restored folder",
    "Restored library": "Restored library",
    "Restored {name}": "Restored {name}",
    "Restored {name} and {n} other items": "Restored {name} and {n} other items",
    "Resubmit": "G\u1eedi l\u1ea1i",
    "Result": "K\u1ebft qu\u1ea3",
    "Revoke Access": "Revoke Access",
    "Revoke Admin": "H\u1ee7y b\u1ecf quy\u1ec1n Admin",
    "Role": "Vai tr\u00f2",
    "SAML config": "SAML config",
    "SAML config updated": "SAML config updated",
    "Save": "L\u01b0u",
    "Save Selected Items": "Save Selected Items",
    "Save to:": "Save to:",
    "Saving...": "\u0110ang l\u01b0u...",
    "Scan the QR code to view the shared content directly": "Scan the QR code to view the shared content directly",
    "SeaTable integration": "SeaTable integration",
    "Seafile": "Seafile",
    "Search": "T\u00ecm ki\u1ebfm",
    "Search Groups": "Search Groups",
    "Search Libraries": "Search Libraries",
    "Search Organizations": "Search Organizations",
    "Search Users": "Search Users",
    "Search collaborator": "T\u00ecm c\u1ed9ng t\u00e1c vi\u00ean",
    "Search collaborators": "Search collaborators",
    "Search department": "T\u00ecm ki\u1ebfm b\u1ed9 ph\u1eadn",
    "Search files": "Search files",
    "Search files in this library": "T\u00ecm trong th\u01b0 vi\u1ec7n",
    "Search groups": "Search groups",
    "Search groups by name": "Search groups by name",
    "Search libraries by name or ID": "Search libraries by name or ID",
    "Search libraries by owner": "Search libraries by owner",
    "Search option": "T\u00ecm ki\u1ebfm t\u00f9y ch\u1ecdn",
    "Search organizations": "Search organizations",
    "Search property": "Search property",
    "Search users": "Search users",
    "Search users...": "T\u00ecm ng\u01b0\u1eddi d\u00f9ng...",
    "Searching...": "\u0110ang t\u00ecm...",
    "Select File": "Select File",
    "Select a department": "Select a department",
    "Select a user": "Select a user",
    "Select a user as admin": "Select a user as admin",
    "Select all": "Select all",
    "Select an option": "Ch\u1ecdn m\u1ed9t t\u00f9y ch\u1ecdn",
    "Select collaborators": "Select collaborators",
    "Select libraries to share": "Ch\u1ecdn th\u01b0 vi\u1ec7n \u0111\u1ec3 chia s\u1ebb",
    "Select option(s)": "Ch\u1ecdn t\u00f9y ch\u1ecdn(s)",
    "Select up to 50 files": "Select up to 50 files",
    "Send": "G\u1edfi",
    "Send activation Email after user registration.": "Send activation Email after user registration.",
    "Send to:": "G\u1edfi \u0111\u1ebfn:",
    "Sending new password...": "Sending new password...",
    "Sending...": "\u0110ang g\u1edfi...",
    "Server Version: ": "Phi\u00ean b\u1ea3n: ",
    "Set Admin": "Set Admin",
    "Set Contact Email": "Set Contact Email",
    "Set Download Rate Limit": "Set Download Rate Limit",
    "Set Login ID": "Set Login ID",
    "Set Name": "Set Name",
    "Set Password": "Set Password",
    "Set Quota": "Thi\u1ebft l\u1eadp Quota",
    "Set Upload Rate Limit": "Set Upload Rate Limit",
    "Set WebDAV Password": "Set WebDAV Password",
    "Set max number of members": "Set max number of members",
    "Set password": "Set password",
    "Set permission": "C\u00e0i \u0111\u1eb7t quy\u1ec1n",
    "Set permission of {placeholder}": "Set permission of {placeholder}",
    "Set to current": "C\u00e0i \u0111\u1eb7t v\u1ec1 hi\u1ec7n t\u1ea1i",
    "Set user contact email": "Set user contact email",
    "Set user default quota": "Set user default quota",
    "Set user name": "Set user name",
    "Set user quota": "Set user quota",
    "Setting library history is disabled by Admin.": "Setting library history is disabled by Admin.",
    "Settings": "C\u00e0i \u0111\u1eb7t",
    "Share": "Chia s\u1ebb",
    "Share Admin": "Qu\u1ea3n l\u00fd chia s\u1ebb",
    "Share From": "Chia s\u1ebb t\u1eeb",
    "Share Link": "Chia s\u1ebb li\u00ean k\u1ebft",
    "Share Links": "Share Links",
    "Share To": "Chia s\u1ebb \u0111\u1ebfn",
    "Share To:": "Share To:",
    "Share existing libraries": "Chia s\u1ebb th\u01b0 vi\u1ec7n hi\u1ec7n c\u00f3",
    "Share link download": "Share link download",
    "Share link is copied to the clipboard.": "Share link is copied to the clipboard.",
    "Share link upload": "Share link upload",
    "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.": "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.",
    "Share to group": "Share to group",
    "Share to other server": "Share to other server",
    "Share to user": "Share to user",
    "Shared By": "Chia s\u1ebb b\u1edfi",
    "Shared Libraries": "Shared Libraries",
    "Shared Links": "Links chia s\u1ebb",
    "Shared by: ": "\u0110\u01b0\u1ee3c chia s\u1ebb b\u1edfi:",
    "Shared with me": "Shared with me",
    "Show": "Show",
    "Show all": "Hi\u1ec3n th\u1ecb t\u1ea5t c\u1ea3",
    "Show changes": "Show changes",
    "Side Nav Menu": "Side Nav Menu",
    "Single select": "Single select",
    "Site name used in email sending": "Site name used in email sending",
    "Site title shown in a browser tab": "Site title shown in a browser tab",
    "Size": "Dung l\u01b0\u1ee3ng",
    "Sort": "S\u1eafp x\u1ebfp",
    "Sort ascending": "Sort ascending",
    "Sort descending": "Sort descending",
    "Space Used": "Dung l\u01b0\u1ee3ng \u0111\u00e3 d\u00f9ng",
    "Space Used / Quota": "Space Used / Quota",
    "Specific people with email address": "Specific people with email address",
    "Specific users in the team": "Specific users in the team",
    "Star": "\u0110\u00e1nh d\u1ea5u",
    "Start date": "Start date",
    "Status": "Tr\u1ea1ng th\u00e1i",
    "Status: enabled": "Status: enabled",
    "Storage": "Storage",
    "Storage Backend": "Storage Backend",
    "Storage Used": "Storage Used",
    "Style": "Ki\u1ec3u",
    "Submit": "C\u1eadp nh\u1eadt",
    "Success": "Th\u00e0nh c\u00f4ng",
    "Successfully added label(s) for library {placeholder}": "Successfully added label(s) for library {placeholder}",
    "Successfully change the group": "Successfully change the group",
    "Successfully changed library password.": "Successfully changed library password.",
    "Successfully cleared trash.": "Successfully cleared trash.",
    "Successfully converted the file.": "Successfully converted the file.",
    "Successfully copied %(name)s and %(amount)s other items.": "Sao ch\u00e9p %(name)s v\u00e0 %(amount)s item kh\u00e1c th\u00e0nh c\u00f4ng.",
    "Successfully copied %(name)s and 1 other item.": "Sao ch\u00e9p %(name)s v\u00e0 1 item kh\u00e1c th\u00e0nh c\u00f4ng.",
    "Successfully copied %(name)s.": "Sao ch\u00e9p %(name)s th\u00e0nh c\u00f4ng.",
    "Successfully copied files to another library.": "Successfully copied files to another library.",
    "Successfully deleted 1 item.": "Successfully deleted 1 item.",
    "Successfully deleted 1 share link": "Successfully deleted 1 share link",
    "Successfully deleted 1 user.": "Successfully deleted 1 user.",
    "Successfully deleted {name}": "Successfully deleted {name}",
    "Successfully deleted {name} and {n} other items": "Successfully deleted {name} and {n} other items",
    "Successfully deleted {name} and {n} other items.": "Successfully deleted {name} and {n} other items.",
    "Successfully deleted {name}.": "Successfully deleted {name}.",
    "Successfully deleted {number_placeholder} share links": "Successfully deleted {number_placeholder} share links",
    "Successfully deleted {user_number_placeholder} users.": "Successfully deleted {user_number_placeholder} users.",
    "Successfully edited labels.": "Successfully edited labels.",
    "Successfully invited %(email) and %(num) other people.": "Successfully invited %(email) and %(num) other people.",
    "Successfully invited %(email).": "Successfully invited %(email).",
    "Successfully moved %(name)s and %(amount)s other items.": "Di chuy\u1ec3n %(name)s v\u00e0 %(amount)s item kh\u00e1c th\u00e0nh c\u00f4ng.",
    "Successfully moved %(name)s and 1 other item.": "Di chuy\u1ec3n %(name)s v\u00e0 1 item kh\u00e1c th\u00e0nh c\u00f4ng.",
    "Successfully moved %(name)s.": "Di chuy\u1ec3n %(name)s th\u00e0nh c\u00f4ng.",
    "Successfully moved files to another library.": "Successfully moved files to another library.",
    "Successfully moved {name}.": "Successfully moved {name}.",
    "Successfully restored the library {library_name}.": "Successfully restored the library {library_name}.",
    "Successfully restored the library.": "Successfully restored the library.",
    "Successfully restored.": "Successfully restored.",
    "Successfully revoke the admin permission of %s": "H\u1ee7y quy\u1ec1n admin c\u1ee7a %s th\u00e0nh c\u00f4ng",
    "Successfully revoked access of user {placeholder}.": "Successfully revoked access of user {placeholder}.",
    "Successfully revoked the admin permission of {placeholder}.": "Successfully revoked the admin permission of {placeholder}.",
    "Successfully saved": "Successfully saved",
    "Successfully sent to {placeholder}": "G\u1edfi th\u00e0nh c\u00f4ng \u0111\u1ebfn {placeholder}",
    "Successfully set %s as admin.": "Thi\u1ebft l\u1eadp quy\u1ec1n admin cho %s th\u00e0nh c\u00f4ng",
    "Successfully set it.": "Successfully set it.",
    "Successfully set library history.": "Successfully set library history.",
    "Successfully starred {library_name_placeholder}.": "Successfully starred {library_name_placeholder}.",
    "Successfully transferred the group.": "Successfully transferred the group.",
    "Successfully transferred the library.": "Successfully transferred the library.",
    "Successfully unlinked the device.": "Successfully unlinked the device.",
    "Successfully unshared {name}": "Successfully unshared {name}",
    "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
    "Suggestion": "G\u1ee3i \u00fd",
    "Switch sort mode": "Switch sort mode",
    "Switch to plain text editor": "Chuy\u1ec3n sang tr\u00ecnh so\u1ea1n th\u1ea3o v\u0103n b\u1ea3n",
    "Switch to rich text editor": "Chuy\u1ec3n sang tr\u00ecnh so\u1ea1n th\u1ea3o v\u0103n b\u1ea3n n\u00e2ng cao",
    "Switch view mode": "Switch view mode",
    "Sync": "Sync",
    "Sync Download": "Sync Download",
    "Sync Upload": "Sync Upload",
    "System": "H\u1ec7 th\u1ed1ng",
    "System Admin": "System Admin",
    "System Info": "Th\u00f4ng tin h\u1ec7 th\u1ed1ng",
    "System settings updated": "System settings updated",
    "Table": "B\u1ea3ng con",
    "Tag not found": "Kh\u00f4ng c\u00f3 t\u00f9y ch\u1ecdn n\u00e0o",
    "Tagged Files": "Tagged Files",
    "Tags": "Th\u1ebb",
    "Team name": "Team name",
    "Template": "Template",
    "Terms": "Terms",
    "Terms and Conditions": "Terms and Conditions",
    "Text": "Text",
    "Text is required.": "Text is required.",
    "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved": "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved",
    "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved": "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved",
    "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.": "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.",
    "The file is too large. Allowed maximum size is 1MB.": "The file is too large. Allowed maximum size is 1MB.",
    "The imported options are invalid": "The imported options are invalid",
    "The least number of characters a share/upload link password should include.": "The least number of characters a share/upload link password should include.",
    "The least number of characters an encrypted library password should include.": "The least number of characters an encrypted library password should include.",
    "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols",
    "The link is copied to the clipboard.": "The link is copied to the clipboard.",
    "The list of added, deleted and modified files will be sent to your mailbox.": "The list of added, deleted and modified files will be sent to your mailbox.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "The maximum number of failed login attempts before showing CAPTCHA.",
    "The name \"{name}\" is already taken. Please choose a different name.": "The name \"{name}\" is already taken. Please choose a different name.",
    "The next month": "The next month",
    "The next numbers of days": "The next numbers of days",
    "The next week": "The next week",
    "The next year": "The next year",
    "The owner of this library has run out of space.": "Ch\u1ee7 th\u01b0 vi\u1ec7n n\u00e0y \u0111\u00e3 d\u00f9ng h\u1ebft dung l\u01b0\u1ee3ng",
    "The password is too short.": "The password is too short.",
    "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.": "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.",
    "The password will be kept in the server for only 1 hour.": "M\u1eadt kh\u1ea9u ch\u1ec9 \u0111\u01b0\u1ee3c l\u01b0u t\u1ea1m tr\u00ean m\u00e1y ch\u1ee7 trong 1 gi\u1edd.",
    "The past month": "The past month",
    "The past numbers of days": "The past numbers of days",
    "The past week": "The past week",
    "The past year": "The past year",
    "There is another option with this name": "There is another option with this name",
    "There is another property with this name": "There is another property with this name",
    "There is no information to display.": "There is no information to display.",
    "This file has been updated.": "T\u1ec7p n\u00e0y \u0111\u00e3 \u0111\u01b0\u1ee3c c\u1eadp nh\u1eadt",
    "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This folder has no content at this time.": "This folder has no content at this time.",
    "This is a special group representing a department.": "This is a special group representing a department.",
    "This is required": "This is required",
    "This library has been set to read-only by admin and cannot be updated.": "This library has been set to read-only by admin and cannot be updated.",
    "This library has been shared to {user_amount} user(s) and {group_amount} group(s).": "This library has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This library is password protected": "Th\u01b0 vi\u1ec7n n\u00e0y b\u1ea3o v\u1ec7 v\u1edbi m\u1eadt kh\u1ea9u",
    "This month": "This month",
    "This operation will not be reverted. Please think twice!": "X\u00f3a t\u00e0i kho\u1ea3n s\u1ebd kh\u00f4ng th\u1ec3 ph\u1ee5c h\u1ed3i. Vui l\u00f2ng suy ngh\u0129 l\u1ea7n n\u1eefa!",
    "This property can not be deleted": "This property can not be deleted",
    "This property does not support sorting": "This property does not support sorting",
    "This property is not editable": "This property is not editable",
    "This user has not created or joined any groups": "Ng\u01b0\u1eddi d\u00f9ng n\u00e0y ch\u01b0a tao ho\u1eb7c tham gia nh\u00f3m n\u00e0o",
    "This week": "This week",
    "This year": "This year",
    "Thumbnail": "Thumbnail",
    "Time": "Th\u1eddi gian",
    "Tip: -2 means no limit.": "Tip: -2 means no limit.",
    "Tip: 0 means default limit": "M\u1eb9o: \u0111i\u1ec1n 0 cho thi\u1ebft l\u1eadp kh\u00f4ng gi\u1edbi h\u1ea1n",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tip: a snapshot will be generated after modification, which records the library state after the modification.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.",
    "Tip: you can search by keyword in name or ID.": "Tip: you can search by keyword in name or ID.",
    "Tip: you can search by keyword in name.": "Tip: you can search by keyword in name.",
    "Today": "Today",
    "Token": "Token",
    "Token:": "Token:",
    "Tomorrow": "Tomorrow",
    "Too many requests": "Too many requests",
    "Total Devices": "Total Devices",
    "Total Storage": "Total Storage",
    "Total Users": "T\u1ed5ng s\u1ed1 ng\u01b0\u1eddi d\u00f9ng",
    "Traffic": "B\u0103ng th\u00f4ng",
    "Transfer": "Chuy\u1ec3n",
    "Transfer Group": "Transfer Group",
    "Transfer Group {placeholder} to": "Transfer Group {placeholder} to",
    "Transfer Library": "Chuy\u1ec3n th\u01b0 vi\u1ec7n",
    "Transfer Library {library_name}": "Transfer Library {library_name}",
    "Transfer group to": "Transfer group to",
    "Transfer to department": "Transfer to department",
    "Transfer to user": "Transfer to user",
    "Transferred group {group_name} from {user_from} to {user_to}": "Transferred group {group_name} from {user_from} to {user_to}",
    "Transferred library {library_name} from {user_from} to {user_to}": "Transferred library {library_name} from {user_from} to {user_to}",
    "Trash": "Th\u00f9ng r\u00e1c",
    "Turn off": "Turn off",
    "Turn off extended properties": "Turn off extended properties",
    "Turn on extensible properties and views to experience a new way of managing files": "Turn on extensible properties and views to experience a new way of managing files",
    "Two-Factor Authentication": "Two-Factor Authentication",
    "Type": "Type",
    "Type characters to start search": "Type characters to start search",
    "URL is copied to the clipboard": "URL is copied to the clipboard",
    "URL is required": "URL is required",
    "US": "US",
    "Undo": "Undo",
    "Unfreeze Document": "Unfreeze Document",
    "Unhandled": "Unhandled",
    "Unknown": "Kh\u00f4ng x\u00e1c \u0111\u1ecbnh",
    "Unlink": "B\u1ecf li\u00ean k\u1ebft",
    "Unlink device": "Unlink device",
    "Unlock": "M\u1edf kh\u00f3a",
    "Unresolved comments": "B\u00ecnh lu\u1eadn ch\u01b0a gi\u1ea3i quy\u1ebft",
    "Unselect": "Unselect",
    "Unshare": "Ng\u1eebng chia s\u1ebb",
    "Unstar": "H\u1ee7y \u0111\u00e1nh d\u1ea5u",
    "Untitled": "Untitled",
    "Unwatch File Changes": "Unwatch File Changes",
    "Up": "L\u00ean",
    "Update": "C\u1eadp nh\u1eadt",
    "Update Terms and Conditions": "Update Terms and Conditions",
    "Update password": "Update password",
    "Update succeeded.": "Update succeeded.",
    "Updated draft": "Updated draft",
    "Updated file": "Updated file",
    "Upgrade to Pro Edition": "N\u00e2ng c\u1ea5p l\u00ean phi\u00ean b\u1ea3n Professional",
    "Upload": "T\u1ea3i l\u00ean",
    "Upload Files": "T\u1ea3i d\u1eef li\u1ec7u",
    "Upload Folder": "Th\u01b0 m\u1ee5c t\u1ea3i l\u00ean",
    "Upload Link": "Upload Link",
    "Upload Links": "Link t\u1ea3i l\u00ean",
    "Upload license": "Upload license",
    "Upload link is copied to the clipboard.": "Upload link is copied to the clipboard.",
    "Uploading...": "Uploading...",
    "Use custom CSS": "Use custom CSS",
    "Use information from your Identity Provider to configure Seafile": "Use information from your Identity Provider to configure Seafile",
    "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.": "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.",
    "Use these values to configure your Identity Provider": "Use these values to configure your Identity Provider",
    "Used:": "\u0110\u00e3 d\u00f9ng",
    "User": "Ng\u01b0\u1eddi d\u00f9ng",
    "User Permission": "User Permission",
    "User Shares": "User Shares",
    "User Storage": "User Storage",
    "User can not see this folder.": "User can not see this folder.",
    "User can only view files online via browser. Files can't be downloaded.": "User can only view files online via browser. Files can't be downloaded.",
    "User can read, download and sync files.": "User can read, download and sync files.",
    "User can read, write, upload, download and sync files.": "User can read, write, upload, download and sync files.",
    "User can view and edit file online via browser. Files can't be downloaded.": "User can view and edit file online via browser. Files can't be downloaded.",
    "User info updated": "User info updated",
    "User migrate from {user_from} to {user_to}": "User migrate from {user_from} to {user_to}",
    "User not found": "User not found",
    "User {user_link} has added you to {group_link}": "User {user_link} has added you to {group_link}",
    "Username:": "T\u00ean \u0111\u0103ng nh\u1eadp",
    "Users": "Ng\u01b0\u1eddi d\u00f9ng",
    "Verified": "Verified",
    "Verify": "Verify",
    "Verify Domain": "Verify Domain",
    "Version": "Version",
    "Version Number": "Version Number",
    "Version Number is required.": "Version Number is required.",
    "Version Number must be a number.": "Version Number must be a number.",
    "Video": "Video",
    "View": "Xem",
    "View Link": "View Link",
    "View Related Snapshot": "View Related Snapshot",
    "View profile and more": "View profile and more",
    "Views": "Views",
    "Virus": "Virus",
    "Virus File": "Virus File",
    "Visit count": "Visit count",
    "Visit old version page": "Visit old version page",
    "Visited": "Visited",
    "Visits": "# Truy c\u1eadp",
    "Watch File Changes": "Watch File Changes",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Web Download",
    "Web Upload": "Web Upload",
    "WebDAV Access": "WebDAV Access",
    "WebDAV password:": "WebDAV password:",
    "WebDAV username:": "WebDAV username:",
    "Wiki custom URL deleted": "Wiki custom URL deleted",
    "Wiki owner": "Wiki owner",
    "Wiki published": "Wiki published",
    "Wikis": "Wikis",
    "Wrong password": "Sai m\u1eadt kh\u1ea9u",
    "Year": "Year",
    "Yesterday": "Yesterday",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "B\u1ea1n c\u00f3 th\u1ec3 th\u00eam t\u00e0i kho\u1ea3n 'Kh\u00e1ch' nh\u01b0 ng\u01b0\u1eddi d\u00f9ng, nh\u01b0ng kh\u00f4ng t\u1ea1o \u0111\u01b0\u1ee3c th\u01b0 vi\u1ec7n v\u00e0 nh\u00f3m.",
    "You can create files quickly": "You can create files quickly",
    "You can enter multiple emails. An invitation link will be sent to each of them.": "You can enter multiple emails. An invitation link will be sent to each of them.",
    "You can use this field at login.": "B\u1ea1n c\u00f3 th\u1ec3 ch\u1ecdn feild n\u00e0y khi \u0111\u0103ng nh\u1eadp",
    "You do not have permission": "You do not have permission",
    "You don't have any favorite items yet": "You don't have any favorite items yet",
    "You don't have any share links": "You don't have any share links",
    "You don't have any upload links": "You don't have any upload links",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.",
    "You have not shared any folders": "You have not shared any folders",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".",
    "Your notifications will be sent to this email.": "Th\u00f4ng b\u00e1o s\u1ebd \u0111\u01b0\u1ee3c g\u1edfi \u0111\u1ebfn email c\u1ee7a b\u1ea1n.",
    "all": "t\u1ea5t c\u1ea3",
    "all members": "t\u1ea5t c\u1ea3 th\u00e0nh vi\u00ean",
    "contains": "Ch\u1ee9a",
    "days": "Ng\u00e0y",
    "deleted": "deleted",
    "deleted option": "deleted option",
    "details": "details",
    "does not contain": "Kh\u00f4ng ch\u1ee9a",
    "email is required": "email is required",
    "freezed": "freezed",
    "has all of...": "has all of...",
    "has any of...": "has any of...",
    "has none of...": "has none of...",
    "icon": "icon",
    "in all libraries": "in all libraries",
    "include the current user": " Bao g\u1ed3m t\u00f4i",
    "is": "L\u00e0",
    "is after...": "is after...",
    "is any of...": "is any of...",
    "is before...": "is before...",
    "is current user's ID": "ID ng\u01b0\u1eddi d\u00f9ng hi\u1ec7n t\u1ea1i",
    "is empty": "Tr\u1ed1ng",
    "is exactly...": "is exactly...",
    "is none of...": "is none of...",
    "is not": "Kh\u00f4ng ph\u1ea3i",
    "is not empty": "Kh\u00f4ng tr\u1ed1ng",
    "is on or after...": "is on or after...",
    "is on or before...": "is on or before...",
    "is within...": "is within...",
    "items": "items",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}",
    "locked": "\u0111\u00e3 kh\u00f3a",
    "locked by {name}": "locked by {name}",
    "mm": "mm",
    "name": "T\u00ean",
    "not set": "not set",
    "only show {placeholder}": "only show {placeholder}",
    "s": "s",
    "selected": "selected",
    "show more": "show more",
    "sorts": "S\u1eafp x\u1ebfp",
    "starred": "\u0111\u00e1nh d\u1ea5u",
    "successfully added user %s.": "successfully added user %s.",
    "successfully sent email to %s.": "successfully sent email to %s.",
    "unstarred": "b\u1ecf \u0111\u00e1nh d\u1ea5u",
    "xxx cells copied": "xxx cells copied",
    "xxx cells selected": "xxx cells selected",
    "xxx record": "xxx record",
    "xxx records": "xxx records",
    "xxx records selected": "xxx records selected",
    "xxx rows are copied.": "xxx rows are copied.",
    "you can also press \u2192": "you can also press \u2192",
    "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
    "{file} and {n} other files": "{file} and {n} other files",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
    "{number_placeholder} / Page": "{number_placeholder} / Page",
    "{placeholder} Access Log": "{placeholder} Access Log",
    "{placeholder} Folder Permission": "{placeholder} Folder Permission",
    "{placeholder} History Setting": "{placeholder} History Setting",
    "{placeholder} Modification History": "{placeholder} Modification History",
    "{placeholder} Share Admin": "{placeholder} Share Admin",
    "{placeholder} Snapshot": "{placeholder} Snapshot",
    "{placeholder} Trash": "{placeholder} Trash",
    "{placeholder} Wiki Trash": "{placeholder} Wiki Trash",
    "{share_from} has cancelled the sharing of folder {repo_name}.": "{share_from} has cancelled the sharing of folder {repo_name}.",
    "{share_from} has cancelled the sharing of library {repo_name}.": "{share_from} has cancelled the sharing of library {repo_name}.",
    "{share_from} has changed the permission of folder {repo_link} to {permission}.": "{share_from} has changed the permission of folder {repo_link} to {permission}.",
    "{share_from} has changed the permission of library {repo_link} to {permission}.": "{share_from} has changed the permission of library {repo_link} to {permission}.",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} has shared a folder named {repo_link} to group {group_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} has shared a folder named {repo_link} to you.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} has shared a library named {repo_link} to group {group_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} has shared a library named {repo_link} to you.",
    "{uploaded_files_num}/{all_files_num} Files": "{uploaded_files_num}/{all_files_num} Files",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.",
    "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} created file {fileName} in library {libraryName}.": "{user} created file {fileName} in library {libraryName}.",
    "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} created folder {folderName} in library {libraryName}.": "{user} created folder {folderName} in library {libraryName}.",
    "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} deleted file {fileName} in library {libraryName}.": "{user} deleted file {fileName} in library {libraryName}.",
    "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} deleted folder {folderName} in library {libraryName}.": "{user} deleted folder {folderName} in library {libraryName}.",
    "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} moved file {fileName} in library {libraryName}.": "{user} moved file {fileName} in library {libraryName}.",
    "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} moved folder {folderName} in library {libraryName}.": "{user} moved folder {folderName} in library {libraryName}.",
    "{user} renamed file {oldFileName} {fileName} in library {libraryName}.": "{user} renamed file {oldFileName} {fileName} in library {libraryName}.",
    "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.": "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.",
    "{user} restored file {fileName} in library {libraryName}.": "{user} restored file {fileName} in library {libraryName}.",
    "{user} restored folder {folderName} in library {libraryName}.": "{user} restored folder {folderName} in library {libraryName}.",
    "{user} updated file {fileName} in library {libraryName}.": "{user} updated file {fileName} in library {libraryName}."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "H:i \\N\\g\u00e0\\y d \\t\\h\u00e1\\n\\g n \\n\u0103\\m Y",
    "DATETIME_INPUT_FORMATS": [
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%m/%d/%Y %H:%M:%S",
      "%m/%d/%Y %H:%M:%S.%f",
      "%m/%d/%Y %H:%M",
      "%m/%d/%y %H:%M:%S",
      "%m/%d/%y %H:%M:%S.%f",
      "%m/%d/%y %H:%M"
    ],
    "DATE_FORMAT": "\\N\\g\u00e0\\y d \\t\\h\u00e1\\n\\g n \\n\u0103\\m Y",
    "DATE_INPUT_FORMATS": [
      "%Y-%m-%d",
      "%m/%d/%Y",
      "%m/%d/%y",
      "%b %d %Y",
      "%b %d, %Y",
      "%d %b %Y",
      "%d %b, %Y",
      "%B %d %Y",
      "%B %d, %Y",
      "%d %B %Y",
      "%d %B, %Y"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 0,
    "MONTH_DAY_FORMAT": "j F",
    "NUMBER_GROUPING": 0,
    "SHORT_DATETIME_FORMAT": "H:i d-m-Y",
    "SHORT_DATE_FORMAT": "d-m-Y",
    "THOUSAND_SEPARATOR": ".",
    "TIME_FORMAT": "H:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H:%M:%S.%f",
      "%H:%M"
    ],
    "YEAR_MONTH_FORMAT": "F Y"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

